currentPositionButtonText property
currentPositionButtonText : (String) change the text of the button selecting current position
Implementation
final String currentPositionButtonText;
currentPositionButtonText : (String) change the text of the button selecting current position
final String currentPositionButtonText;