UserAgent class

An User-Agent is an http request header that is sent with each request. OpenStreetMap’s Nominatim service (used for geocoding) requires a user-agent to identify your application. If you don’t provide one, your requests might get blocked or throttled.

Constructors

UserAgent({required String appName, required String email, String? version = "1.0"})

Properties

appName String
The name of your application (eg: geo-app)
final
email String
Email contact. OSM Nominatim asks that the user_agent also contains your email address (eg: support@myapp.com)
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
version String?
The version of the application (eg: 1.0.0)
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited