flutter_location_search2 library

Classes

HistoryManager
LatLong
LocationData
LocationSearch
LocationSearchWidget
Principal widget to show Flutter map using osm api with search bar. you can track you current location, search for a location and select it. navigate easily in the map to selecte location.
UserAgent
An User-Agent is an http request header that is sent with each request. OpenStreetMap’s Nominatim service (used for geocoding) requires a user-agent to identify your application. If you don’t provide one, your requests might get blocked or throttled.

Enums

Mode