LocationSearch class
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited
Static Methods
-
show({required BuildContext context, void onError(Exception e)?, String language = 'en', List<String>? countryCodes, Color? searchBarBackgroundColor, required UserAgent userAgent, Color searchBarTextColor = Colors.black87, String searchBarHintText = 'Search location', String currentPositionButtonText = 'Use current location', Color searchBarHintColor = Colors.black87, bool lightAddress = false, Color iconColor = Colors.grey, Widget? loadingWidget, Widget upperWidget(BuildContext context)?, String? googlePlacesSearchKey, Mode mode = Mode.fullscreen, int historyMaxLength = 5, bool showAddressNumberOption = true, String addressNumberButtonText = "Add number", IconData? addressNumberButtonIcon = Icons.add, Color? addressNumberButtonColor, Color? addressNumberButtonBackground, double addressNumberButtonTextSize = 12})
→ Future<LocationData?>
-